@@ -13,17 +13,12 @@ from git.exc import InvalidGitRepositoryError
 import gitgud
 from gitgud.operations import get_operator
 from gitgud.operations import Operator
-from gitgud.operations import clear_tracked_commits
 from gitgud.skills import all_skills
-from gitgud.skills.util import print_all_complete
+from gitgud.skills.user_messages import all_levels_complete
+from gitgud.skills.user_messages import show_tree
 from gitgud.hooks import all_hooks
 
 
-def show_tree():
-    print("Simulating: git log --graph --oneline --all ")
-    subprocess.call(["git", "log", "--graph", "--oneline", "--all"])
-
-
 class InitializationError(Exception):
     pass
 
@@ -71,6 +66,17 @@ class GitGud:
             "   git gud load -<level>",
             "\n",
         ])
+        
+        show_description = "".join([
+            "Helper command to show certain information.",
+            "\n\n",
+            "Subcommands:",
+            "\n",
+            "  <command>",
+            "\n",
+            "    tree", "\t", "Show the current state of the branching tree"
+        ])
+
         self.subparsers = self.parser.add_subparsers(title='Subcommands', metavar='<command>', dest='command')
 
         help_parser = self.subparsers.add_parser('help', help='Show help for commands', description='Show help for commands')
@@ -86,11 +92,13 @@ class GitGud:
         load_parser = self.subparsers.add_parser('load', help='Load a specific skill or level', description=load_description, formatter_class=argparse.RawDescriptionHelpFormatter)
         commit_parser = self.subparsers.add_parser('commit', help='Quickly create and commit a file', description='Quickly create and commit a file')
         goal_parser = self.subparsers.add_parser('goal', help='Show a description of the current goal', description='Show a description of the current goal')
-        show_tree_parser = self.subparsers.add_parser('show-tree', help='Show the current state of the branching tree', description='Show the current state of the branching tree')
+        show_parser = self.subparsers.add_parser('show', description=show_description, formatter_class=argparse.RawDescriptionHelpFormatter)
         contrib_parser = self.subparsers.add_parser('contributors', help='Show project contributors webpage', description='Show all the contributors of the project')
         issues_parser = self.subparsers.add_parser('issues', help='Show project issues webpage', description="Show all the issues for the project")
         
-        help_parser.add_argument('command_name', metavar='<command>', nargs='?')
+        show_parser.add_argument('cmd', metavar='cmd', help='Command to show information', nargs='?')
+
+        help_parser.add_argument('command_name', metavar='cmd', help="Command to get help on", nargs='?')
 
         init_parser.add_argument('--force', action='store_true')
 
@@ -115,6 +123,7 @@ class GitGud:
             'load': self.handle_load,
             'commit': self.handle_commit,
             'show-tree': self.handle_show_tree,
+            'show': self.handle_show,
             'contributors': self.handle_contrib,
             'issues': self.handle_issues    
         }
@@ -134,10 +143,9 @@ class GitGud:
                 raise InitializationError('Currently loaded level does not exist: "{}"'.format(level_name))
 
     def load_level(self, level):
-        clear_tracked_commits(self.file_operator)
+        self.file_operator.clear_tracked_commits()
         level.setup(self.file_operator)
         self.file_operator.write_level(level)
-        show_tree()
 
     def handle_help(self, args):
         if args.command_name is None:
@@ -187,9 +195,9 @@ class GitGud:
 
         python_exec = sys.executable.replace('\\', '/')  # Git uses unix-like path separators
 
-        for git_hook_name, module_hook_name in all_hooks:
+        for git_hook_name, module_hook_name, accepts_args in all_hooks:
             path = os.path.join(self.file_operator.hooks_path, git_hook_name)
-            if git_hook_name in ('commit-msg', 'post-rebase'):
+            if accepts_args:
                 pipeline = 'cat - |'
                 passargs = ' "$@"'
             else:
@@ -210,16 +218,13 @@ class GitGud:
             mode |= (mode & 0o444) >> 2
             os.chmod(path, mode)
 
-        print('Git Gud successfully setup in {}\n'.format(os.getcwd()))
-        print(files('gitgud').joinpath('welcome.txt').read_text())
-
-        self.load_level(all_skills["1"]["1"])
+        self.load_level(all_skills["0"]["1"])
 
     def handle_status(self, args):
         if self.is_initialized():
             try:
                 level = self.file_operator.get_level()
-                print('Currently on level: "{}"'.format(level.full_name()))
+                level.status()
             except KeyError:
                 level_name = self.file_operator.read_level_file()
                 print('Currently on unregistered level: "{}"'.format(level_name))
@@ -239,7 +244,6 @@ class GitGud:
         self.assert_initialized()
 
         level = self.file_operator.get_level()
-        print("Resetting...")
         self.load_level(level)
 
     def handle_test(self, args):
@@ -256,13 +260,20 @@ class GitGud:
             except KeyError:
                 pass
         
-        skill_chars = max(len(skill.name) for skill in all_skills)
-        skill_format_template = 'Skill {{}} - "{{:<{}}}" :{{:>2}} level{{}}'.format(skill_chars)
+        # Add two for quotes
+        skill_formatted_len = max(len(skill.name) for skill in all_skills) + 2
+
+        skill_format_template = 'Skill {skill_number} - {formatted_skill_name} : {num_levels:>2} level{plural}'
         level_format_template = "    Level {:>2} : {:<3}"
         
-        for i, skill in enumerate(all_skills):
+        for skill_number, skill in enumerate(all_skills):
             # TODO Add description
-            print(skill_format_template.format(i + 1, skill.name, len(skill), ("", "s")[len(skill) > 1]))
+            print(skill_format_template.format(
+                skill_number=skill_number,
+                formatted_skill_name='"{}"'.format(skill.name).ljust(skill_formatted_len),
+                num_levels=len(skill),
+                plural="s" if len(skill) > 1 else ""
+            ))
 
             for index, level in enumerate(skill):
                 print(level_format_template.format(index + 1, level.name))
@@ -327,14 +338,12 @@ class GitGud:
                 else:
                     query = "previous"
                     level_to_load = level.prev_level
-                
-                print("Loading the {} level...\n".format(query))
 
                 if level_to_load is not None:
                     self.load_level(level_to_load)
                 else:
                     if query == "next":
-                        print_all_complete()
+                        all_levels_complete()
                     else:
                         print('Already on the first level. To reload the level, use "git gud reload".')
                     print('\nTo view levels/skills, use "git gud levels" or "git gud skills"')
@@ -382,6 +391,12 @@ class GitGud:
 
         if int(commit_name) > int(last_commit):
             self.file_operator.write_last_commit(commit_name)
+    
+    def handle_show(self, args):
+        if args.cmd == "tree":
+            show_tree()
+        else:
+            print('Error: `git gud show` takes specific arguments. Type `git gud help show` for more information.')
 
     def handle_show_tree(self, args):
         show_tree()
@@ -397,7 +412,11 @@ class GitGud:
     def parse(self):
         args, _ = self.parser.parse_known_args()
         if args.command is None:
-            self.parser.print_help()
+            if not self.is_initialized():
+                print('Currently in an uninitialized directory.')
+                print('Get started by running "git gud init" in a new directory!')
+            else:
+                self.parser.print_help()
         else:
             try:
                 self.command_dict[args.command](args)
